==> openjph-doc-0.24.3-1-any.pkg.tar.zst: usr/share/doc/openjph/search/files_2.js <==
var searchData=
[
  ['ojph_5farch_2ecpp_0',['ojph_arch.cpp',['../ojph__arch_8cpp.html',1,'']]],
  ['ojph_5farch_2eh_1',['ojph_arch.h',['../ojph__arch_8h.html',1,'']]],
  ['ojph_5farg_2eh_2',['ojph_arg.h',['../ojph__arg_8h.html',1,'']]],
  ['ojph_5fbase_2eh_3',['ojph_base.h',['../ojph__base_8h.html',1,'']]],
  ['ojph_5fbitbuffer_5fread_2eh_4',['ojph_bitbuffer_read.h',['../ojph__bitbuffer__read_8h.html',1,'']]],
  ['ojph_5fbitbuffer_5fwrite_2eh_5',['ojph_bitbuffer_write.h',['../ojph__bitbuffer__write_8h.html',1,'']]],
  ['ojph_5fblock_5fcommon_2ecpp_6',['ojph_block_common.cpp',['../ojph__block__common_8cpp.html',1,'']]],
  ['ojph_5fblock_5fcommon_2eh_7',['ojph_block_common.h',['../ojph__block__common_8h.html',1,'']]],
  ['ojph_5fblock_5fdecoder_2eh_8',['ojph_block_decoder.h',['../ojph__block__decoder_8h.html',1,'']]],
  ['ojph_5fblock_5fdecoder32_2ecpp_9',['ojph_block_decoder32.cpp',['../ojph__block__decoder32_8cpp.html',1,'']]],
  ['ojph_5fblock_5fdecoder64_2ecpp_10',['ojph_block_decoder64.cpp',['../ojph__block__decoder64_8cpp.html',1,'']]],
  ['ojph_5fblock_5fdecoder_5favx2_2ecpp_11',['ojph_block_decoder_avx2.cpp',['../ojph__block__decoder__avx2_8cpp.html',1,'']]],
  ['ojph_5fblock_5fdecoder_5fssse3_2ecpp_12',['ojph_block_decoder_ssse3.cpp',['../ojph__block__decoder__ssse3_8cpp.html',1,'']]],
  ['ojph_5fblock_5fdecoder_5fwasm_2ecpp_13',['ojph_block_decoder_wasm.cpp',['../ojph__block__decoder__wasm_8cpp.html',1,'']]],
  ['ojph_5fblock_5fencoder_2ecpp_14',['ojph_block_encoder.cpp',['../ojph__block__encoder_8cpp.html',1,'']]],
  ['ojph_5fblock_5fencoder_2eh_15',['ojph_block_encoder.h',['../ojph__block__encoder_8h.html',1,'']]],
  ['ojph_5fblock_5fencoder_5favx2_2ecpp_16',['ojph_block_encoder_avx2.cpp',['../ojph__block__encoder__avx2_8cpp.html',1,'']]],
  ['ojph_5fblock_5fencoder_5favx512_2ecpp_17',['ojph_block_encoder_avx512.cpp',['../ojph__block__encoder__avx512_8cpp.html',1,'']]],
  ['ojph_5fcodeblock_2ecpp_18',['ojph_codeblock.cpp',['../ojph__codeblock_8cpp.html',1,'']]],
  ['ojph_5fcodeblock_2eh_19',['ojph_codeblock.h',['../ojph__codeblock_8h.html',1,'']]],
  ['ojph_5fcodeblock_5ffun_2ecpp_20',['ojph_codeblock_fun.cpp',['../ojph__codeblock__fun_8cpp.html',1,'']]],
  ['ojph_5fcodeblock_5ffun_2eh_21',['ojph_codeblock_fun.h',['../ojph__codeblock__fun_8h.html',1,'']]],
  ['ojph_5fcodestream_2ecpp_22',['ojph_codestream.cpp',['../ojph__codestream_8cpp.html',1,'']]],
  ['ojph_5fcodestream_2eh_23',['ojph_codestream.h',['../ojph__codestream_8h.html',1,'']]],
  ['ojph_5fcodestream_5favx_2ecpp_24',['ojph_codestream_avx.cpp',['../ojph__codestream__avx_8cpp.html',1,'']]],
  ['ojph_5fcodestream_5favx2_2ecpp_25',['ojph_codestream_avx2.cpp',['../ojph__codestream__avx2_8cpp.html',1,'']]],
  ['ojph_5fcodestream_5fgen_2ecpp_26',['ojph_codestream_gen.cpp',['../ojph__codestream__gen_8cpp.html',1,'']]],
  ['ojph_5fcodestream_5flocal_2ecpp_27',['ojph_codestream_local.cpp',['../ojph__codestream__local_8cpp.html',1,'']]],
  ['ojph_5fcodestream_5flocal_2eh_28',['ojph_codestream_local.h',['../ojph__codestream__local_8h.html',1,'']]],
  ['ojph_5fcodestream_5fsse_2ecpp_29',['ojph_codestream_sse.cpp',['../ojph__codestream__sse_8cpp.html',1,'']]],
  ['ojph_5fcodestream_5fsse2_2ecpp_30',['ojph_codestream_sse2.cpp',['../ojph__codestream__sse2_8cpp.html',1,'']]],
  ['ojph_5fcodestream_5fwasm_2ecpp_31',['ojph_codestream_wasm.cpp',['../ojph__codestream__wasm_8cpp.html',1,'']]],
  ['ojph_5fcolour_2ecpp_32',['ojph_colour.cpp',['../ojph__colour_8cpp.html',1,'']]],
  ['ojph_5fcolour_2eh_33',['ojph_colour.h',['../ojph__colour_8h.html',1,'']]],
  ['ojph_5fcolour_5favx_2ecpp_34',['ojph_colour_avx.cpp',['../ojph__colour__avx_8cpp.html',1,'']]],
  ['ojph_5fcolour_5favx2_2ecpp_35',['ojph_colour_avx2.cpp',['../ojph__colour__avx2_8cpp.html',1,'']]],
  ['ojph_5fcolour_5flocal_2eh_36',['ojph_colour_local.h',['../ojph__colour__local_8h.html',1,'']]],
  ['ojph_5fcolour_5fsse_2ecpp_37',['ojph_colour_sse.cpp',['../ojph__colour__sse_8cpp.html',1,'']]],
  ['ojph_5fcolour_5fsse2_2ecpp_38',['ojph_colour_sse2.cpp',['../ojph__colour__sse2_8cpp.html',1,'']]],
  ['ojph_5fcolour_5fwasm_2ecpp_39',['ojph_colour_wasm.cpp',['../ojph__colour__wasm_8cpp.html',1,'']]],
  ['ojph_5fcompress_2ecpp_40',['ojph_compress.cpp',['../ojph__compress_8cpp.html',1,'']]],
  ['ojph_5fdefs_2eh_41',['ojph_defs.h',['../ojph__defs_8h.html',1,'']]],
  ['ojph_5fexpand_2ecpp_42',['ojph_expand.cpp',['../ojph__expand_8cpp.html',1,'']]],
  ['ojph_5ffile_2ecpp_43',['ojph_file.cpp',['../ojph__file_8cpp.html',1,'']]],
  ['ojph_5ffile_2eh_44',['ojph_file.h',['../ojph__file_8h.html',1,'']]],
  ['ojph_5fimg_5fio_2ecpp_45',['ojph_img_io.cpp',['../ojph__img__io_8cpp.html',1,'']]],
  ['ojph_5fimg_5fio_2eh_46',['ojph_img_io.h',['../ojph__img__io_8h.html',1,'']]],
  ['ojph_5fimg_5fio_5favx2_2ecpp_47',['ojph_img_io_avx2.cpp',['../ojph__img__io__avx2_8cpp.html',1,'']]],
  ['ojph_5fimg_5fio_5fsse41_2ecpp_48',['ojph_img_io_sse41.cpp',['../ojph__img__io__sse41_8cpp.html',1,'']]],
  ['ojph_5fmem_2ecpp_49',['ojph_mem.cpp',['../ojph__mem_8cpp.html',1,'']]],
  ['ojph_5fmem_2eh_50',['ojph_mem.h',['../ojph__mem_8h.html',1,'']]],
  ['ojph_5fmessage_2ecpp_51',['ojph_message.cpp',['../ojph__message_8cpp.html',1,'']]],
  ['ojph_5fmessage_2eh_52',['ojph_message.h',['../ojph__message_8h.html',1,'']]],
  ['ojph_5fparams_2ecpp_53',['ojph_params.cpp',['../ojph__params_8cpp.html',1,'']]],
  ['ojph_5fparams_2eh_54',['ojph_params.h',['../ojph__params_8h.html',1,'']]],
  ['ojph_5fparams_5flocal_2eh_55',['ojph_params_local.h',['../ojph__params__local_8h.html',1,'']]],
  ['ojph_5fprecinct_2ecpp_56',['ojph_precinct.cpp',['../ojph__precinct_8cpp.html',1,'']]],
  ['ojph_5fprecinct_2eh_57',['ojph_precinct.h',['../ojph__precinct_8h.html',1,'']]],
  ['ojph_5fresolution_2ecpp_58',['ojph_resolution.cpp',['../ojph__resolution_8cpp.html',1,'']]],
  ['ojph_5fresolution_2eh_59',['ojph_resolution.h',['../ojph__resolution_8h.html',1,'']]],
  ['ojph_5fsockets_2ecpp_60',['ojph_sockets.cpp',['../ojph__sockets_8cpp.html',1,'']]],
  ['ojph_5fsockets_2eh_61',['ojph_sockets.h',['../ojph__sockets_8h.html',1,'']]],
  ['ojph_5fstream_5fexpand_2ecpp_62',['ojph_stream_expand.cpp',['../ojph__stream__expand_8cpp.html',1,'']]],
  ['ojph_5fsubband_2ecpp_63',['ojph_subband.cpp',['../ojph__subband_8cpp.html',1,'']]],
  ['ojph_5fsubband_2eh_64',['ojph_subband.h',['../ojph__subband_8h.html',1,'']]],
  ['ojph_5fthreads_2ecpp_65',['ojph_threads.cpp',['../ojph__threads_8cpp.html',1,'']]],
  ['ojph_5fthreads_2eh_66',['ojph_threads.h',['../ojph__threads_8h.html',1,'']]],
  ['ojph_5ftile_2ecpp_67',['ojph_tile.cpp',['../ojph__tile_8cpp.html',1,'']]],
  ['ojph_5ftile_2eh_68',['ojph_tile.h',['../ojph__tile_8h.html',1,'']]],
  ['ojph_5ftile_5fcomp_2ecpp_69',['ojph_tile_comp.cpp',['../ojph__tile__comp_8cpp.html',1,'']]],
  ['ojph_5ftile_5fcomp_2eh_70',['ojph_tile_comp.h',['../ojph__tile__comp_8h.html',1,'']]],
  ['ojph_5ftransform_2ecpp_71',['ojph_transform.cpp',['../ojph__transform_8cpp.html',1,'']]],
  ['ojph_5ftransform_2eh_72',['ojph_transform.h',['../ojph__transform_8h.html',1,'']]],
  ['ojph_5ftransform_5favx_2ecpp_73',['ojph_transform_avx.cpp',['../ojph__transform__avx_8cpp.html',1,'']]],
  ['ojph_5ftransform_5favx2_2ecpp_74',['ojph_transform_avx2.cpp',['../ojph__transform__avx2_8cpp.html',1,'']]],
  ['ojph_5ftransform_5favx512_2ecpp_75',['ojph_transform_avx512.cpp',['../ojph__transform__avx512_8cpp.html',1,'']]],
  ['ojph_5ftransform_5flocal_2eh_76',['ojph_transform_local.h',['../ojph__transform__local_8h.html',1,'']]],
  ['ojph_5ftransform_5fsse_2ecpp_77',['ojph_transform_sse.cpp',['../ojph__transform__sse_8cpp.html',1,'']]],
  ['ojph_5ftransform_5fsse2_2ecpp_78',['ojph_transform_sse2.cpp',['../ojph__transform__sse2_8cpp.html',1,'']]],
  ['ojph_5ftransform_5fwasm_2ecpp_79',['ojph_transform_wasm.cpp',['../ojph__transform__wasm_8cpp.html',1,'']]],
  ['ojph_5fversion_2eh_80',['ojph_version.h',['../ojph__version_8h.html',1,'']]],
  ['ojph_5fwrapper_2ecpp_81',['ojph_wrapper.cpp',['../ojph__wrapper_8cpp.html',1,'']]]
];

==> openjph-doc-0.25.2-1-any.pkg.tar.zst: usr/share/doc/openjph/search/files_2.js <==
var searchData=
[
  ['ojph_5farch_2ecpp_0',['ojph_arch.cpp',['../ojph__arch_8cpp.html',1,'']]],
  ['ojph_5farch_2eh_1',['ojph_arch.h',['../ojph__arch_8h.html',1,'']]],
  ['ojph_5farg_2eh_2',['ojph_arg.h',['../ojph__arg_8h.html',1,'']]],
  ['ojph_5fbase_2eh_3',['ojph_base.h',['../ojph__base_8h.html',1,'']]],
  ['ojph_5fbitbuffer_5fread_2eh_4',['ojph_bitbuffer_read.h',['../ojph__bitbuffer__read_8h.html',1,'']]],
  ['ojph_5fbitbuffer_5fwrite_2eh_5',['ojph_bitbuffer_write.h',['../ojph__bitbuffer__write_8h.html',1,'']]],
  ['ojph_5fblock_5fcommon_2ecpp_6',['ojph_block_common.cpp',['../ojph__block__common_8cpp.html',1,'']]],
  ['ojph_5fblock_5fcommon_2eh_7',['ojph_block_common.h',['../ojph__block__common_8h.html',1,'']]],
  ['ojph_5fblock_5fdecoder_2eh_8',['ojph_block_decoder.h',['../ojph__block__decoder_8h.html',1,'']]],
  ['ojph_5fblock_5fdecoder32_2ecpp_9',['ojph_block_decoder32.cpp',['../ojph__block__decoder32_8cpp.html',1,'']]],
  ['ojph_5fblock_5fdecoder64_2ecpp_10',['ojph_block_decoder64.cpp',['../ojph__block__decoder64_8cpp.html',1,'']]],
  ['ojph_5fblock_5fdecoder_5favx2_2ecpp_11',['ojph_block_decoder_avx2.cpp',['../ojph__block__decoder__avx2_8cpp.html',1,'']]],
  ['ojph_5fblock_5fdecoder_5fssse3_2ecpp_12',['ojph_block_decoder_ssse3.cpp',['../ojph__block__decoder__ssse3_8cpp.html',1,'']]],
  ['ojph_5fblock_5fdecoder_5fwasm_2ecpp_13',['ojph_block_decoder_wasm.cpp',['../ojph__block__decoder__wasm_8cpp.html',1,'']]],
  ['ojph_5fblock_5fencoder_2ecpp_14',['ojph_block_encoder.cpp',['../ojph__block__encoder_8cpp.html',1,'']]],
  ['ojph_5fblock_5fencoder_2eh_15',['ojph_block_encoder.h',['../ojph__block__encoder_8h.html',1,'']]],
  ['ojph_5fblock_5fencoder_5favx2_2ecpp_16',['ojph_block_encoder_avx2.cpp',['../ojph__block__encoder__avx2_8cpp.html',1,'']]],
  ['ojph_5fblock_5fencoder_5favx512_2ecpp_17',['ojph_block_encoder_avx512.cpp',['../ojph__block__encoder__avx512_8cpp.html',1,'']]],
  ['ojph_5fcodeblock_2ecpp_18',['ojph_codeblock.cpp',['../ojph__codeblock_8cpp.html',1,'']]],
  ['ojph_5fcodeblock_2eh_19',['ojph_codeblock.h',['../ojph__codeblock_8h.html',1,'']]],
  ['ojph_5fcodeblock_5ffun_2ecpp_20',['ojph_codeblock_fun.cpp',['../ojph__codeblock__fun_8cpp.html',1,'']]],
  ['ojph_5fcodeblock_5ffun_2eh_21',['ojph_codeblock_fun.h',['../ojph__codeblock__fun_8h.html',1,'']]],
  ['ojph_5fcodestream_2ecpp_22',['ojph_codestream.cpp',['../ojph__codestream_8cpp.html',1,'']]],
  ['ojph_5fcodestream_2eh_23',['ojph_codestream.h',['../ojph__codestream_8h.html',1,'']]],
  ['ojph_5fcodestream_5favx_2ecpp_24',['ojph_codestream_avx.cpp',['../ojph__codestream__avx_8cpp.html',1,'']]],
  ['ojph_5fcodestream_5favx2_2ecpp_25',['ojph_codestream_avx2.cpp',['../ojph__codestream__avx2_8cpp.html',1,'']]],
  ['ojph_5fcodestream_5fgen_2ecpp_26',['ojph_codestream_gen.cpp',['../ojph__codestream__gen_8cpp.html',1,'']]],
  ['ojph_5fcodestream_5flocal_2ecpp_27',['ojph_codestream_local.cpp',['../ojph__codestream__local_8cpp.html',1,'']]],
  ['ojph_5fcodestream_5flocal_2eh_28',['ojph_codestream_local.h',['../ojph__codestream__local_8h.html',1,'']]],
  ['ojph_5fcodestream_5fsse_2ecpp_29',['ojph_codestream_sse.cpp',['../ojph__codestream__sse_8cpp.html',1,'']]],
  ['ojph_5fcodestream_5fsse2_2ecpp_30',['ojph_codestream_sse2.cpp',['../ojph__codestream__sse2_8cpp.html',1,'']]],
  ['ojph_5fcodestream_5fwasm_2ecpp_31',['ojph_codestream_wasm.cpp',['../ojph__codestream__wasm_8cpp.html',1,'']]],
  ['ojph_5fcolour_2ecpp_32',['ojph_colour.cpp',['../ojph__colour_8cpp.html',1,'']]],
  ['ojph_5fcolour_2eh_33',['ojph_colour.h',['../ojph__colour_8h.html',1,'']]],
  ['ojph_5fcolour_5favx_2ecpp_34',['ojph_colour_avx.cpp',['../ojph__colour__avx_8cpp.html',1,'']]],
  ['ojph_5fcolour_5favx2_2ecpp_35',['ojph_colour_avx2.cpp',['../ojph__colour__avx2_8cpp.html',1,'']]],
  ['ojph_5fcolour_5flocal_2eh_36',['ojph_colour_local.h',['../ojph__colour__local_8h.html',1,'']]],
  ['ojph_5fcolour_5fsse_2ecpp_37',['ojph_colour_sse.cpp',['../ojph__colour__sse_8cpp.html',1,'']]],
  ['ojph_5fcolour_5fsse2_2ecpp_38',['ojph_colour_sse2.cpp',['../ojph__colour__sse2_8cpp.html',1,'']]],
  ['ojph_5fcolour_5fwasm_2ecpp_39',['ojph_colour_wasm.cpp',['../ojph__colour__wasm_8cpp.html',1,'']]],
  ['ojph_5fcompress_2ecpp_40',['ojph_compress.cpp',['../ojph__compress_8cpp.html',1,'']]],
  ['ojph_5fdefs_2eh_41',['ojph_defs.h',['../ojph__defs_8h.html',1,'']]],
  ['ojph_5fexpand_2ecpp_42',['ojph_expand.cpp',['../ojph__expand_8cpp.html',1,'']]],
  ['ojph_5ffile_2ecpp_43',['ojph_file.cpp',['../ojph__file_8cpp.html',1,'']]],
  ['ojph_5ffile_2eh_44',['ojph_file.h',['../ojph__file_8h.html',1,'']]],
  ['ojph_5fimg_5fio_2ecpp_45',['ojph_img_io.cpp',['../ojph__img__io_8cpp.html',1,'']]],
  ['ojph_5fimg_5fio_2eh_46',['ojph_img_io.h',['../ojph__img__io_8h.html',1,'']]],
  ['ojph_5fimg_5fio_5favx2_2ecpp_47',['ojph_img_io_avx2.cpp',['../ojph__img__io__avx2_8cpp.html',1,'']]],
  ['ojph_5fimg_5fio_5fsse41_2ecpp_48',['ojph_img_io_sse41.cpp',['../ojph__img__io__sse41_8cpp.html',1,'']]],
  ['ojph_5fmem_2ec_49',['ojph_mem.c',['../ojph__mem_8c.html',1,'']]],
  ['ojph_5fmem_2ecpp_50',['ojph_mem.cpp',['../ojph__mem_8cpp.html',1,'']]],
  ['ojph_5fmem_2eh_51',['ojph_mem.h',['../ojph__mem_8h.html',1,'']]],
  ['ojph_5fmessage_2ecpp_52',['ojph_message.cpp',['../ojph__message_8cpp.html',1,'']]],
  ['ojph_5fmessage_2eh_53',['ojph_message.h',['../ojph__message_8h.html',1,'']]],
  ['ojph_5fparams_2ecpp_54',['ojph_params.cpp',['../ojph__params_8cpp.html',1,'']]],
  ['ojph_5fparams_2eh_55',['ojph_params.h',['../ojph__params_8h.html',1,'']]],
  ['ojph_5fparams_5flocal_2eh_56',['ojph_params_local.h',['../ojph__params__local_8h.html',1,'']]],
  ['ojph_5fprecinct_2ecpp_57',['ojph_precinct.cpp',['../ojph__precinct_8cpp.html',1,'']]],
  ['ojph_5fprecinct_2eh_58',['ojph_precinct.h',['../ojph__precinct_8h.html',1,'']]],
  ['ojph_5fresolution_2ecpp_59',['ojph_resolution.cpp',['../ojph__resolution_8cpp.html',1,'']]],
  ['ojph_5fresolution_2eh_60',['ojph_resolution.h',['../ojph__resolution_8h.html',1,'']]],
  ['ojph_5fsockets_2ecpp_61',['ojph_sockets.cpp',['../ojph__sockets_8cpp.html',1,'']]],
  ['ojph_5fsockets_2eh_62',['ojph_sockets.h',['../ojph__sockets_8h.html',1,'']]],
  ['ojph_5fstream_5fexpand_2ecpp_63',['ojph_stream_expand.cpp',['../ojph__stream__expand_8cpp.html',1,'']]],
  ['ojph_5fsubband_2ecpp_64',['ojph_subband.cpp',['../ojph__subband_8cpp.html',1,'']]],
  ['ojph_5fsubband_2eh_65',['ojph_subband.h',['../ojph__subband_8h.html',1,'']]],
  ['ojph_5fthreads_2ecpp_66',['ojph_threads.cpp',['../ojph__threads_8cpp.html',1,'']]],
  ['ojph_5fthreads_2eh_67',['ojph_threads.h',['../ojph__threads_8h.html',1,'']]],
  ['ojph_5ftile_2ecpp_68',['ojph_tile.cpp',['../ojph__tile_8cpp.html',1,'']]],
  ['ojph_5ftile_2eh_69',['ojph_tile.h',['../ojph__tile_8h.html',1,'']]],
  ['ojph_5ftile_5fcomp_2ecpp_70',['ojph_tile_comp.cpp',['../ojph__tile__comp_8cpp.html',1,'']]],
  ['ojph_5ftile_5fcomp_2eh_71',['ojph_tile_comp.h',['../ojph__tile__comp_8h.html',1,'']]],
  ['ojph_5ftransform_2ecpp_72',['ojph_transform.cpp',['../ojph__transform_8cpp.html',1,'']]],
  ['ojph_5ftransform_2eh_73',['ojph_transform.h',['../ojph__transform_8h.html',1,'']]],
  ['ojph_5ftransform_5favx_2ecpp_74',['ojph_transform_avx.cpp',['../ojph__transform__avx_8cpp.html',1,'']]],
  ['ojph_5ftransform_5favx2_2ecpp_75',['ojph_transform_avx2.cpp',['../ojph__transform__avx2_8cpp.html',1,'']]],
  ['ojph_5ftransform_5favx512_2ecpp_76',['ojph_transform_avx512.cpp',['../ojph__transform__avx512_8cpp.html',1,'']]],
  ['ojph_5ftransform_5flocal_2eh_77',['ojph_transform_local.h',['../ojph__transform__local_8h.html',1,'']]],
  ['ojph_5ftransform_5fsse_2ecpp_78',['ojph_transform_sse.cpp',['../ojph__transform__sse_8cpp.html',1,'']]],
  ['ojph_5ftransform_5fsse2_2ecpp_79',['ojph_transform_sse2.cpp',['../ojph__transform__sse2_8cpp.html',1,'']]],
  ['ojph_5ftransform_5fwasm_2ecpp_80',['ojph_transform_wasm.cpp',['../ojph__transform__wasm_8cpp.html',1,'']]],
  ['ojph_5fversion_2eh_81',['ojph_version.h',['../ojph__version_8h.html',1,'']]],
  ['ojph_5fwrapper_2ecpp_82',['ojph_wrapper.cpp',['../ojph__wrapper_8cpp.html',1,'']]]
];
